==> provider_software_3.5.2.tar.gz: provider_software_3.5.2/setup.py <==
#!/usr/bin/env python

# ****************************************
# +++  BioCASE Provider Software
# +++  Installer script
# ****************************************

'''
$RCSfile: $
$Revision: 1356 $
$Author: j.holetschek $
$Date: 2014-04-01 16:24:54 +0200 (Di, 01. Apr 2014) $
'''

import sys, os, shutil

# adjust syspath for biocase lib
execfile(os.path.abspath(os.path.join(os.path.dirname(__file__), 'lib', 'biocase', 'adjustpath.py')))

from biocase import __version__ as version
from biocase.configuration import Cfg

INTRO = '''
 +++  BioCASe Provider Software
 +++  Version %s
 +++  Installer script

 Configure BPS with:
 Python      %s
 BPS Library %s

This setup tool adapts the BioCASe Provider Software (BPS) to your system environment.
You can cancel it by hitting Ctrl-Z + Return (Windows) or Ctrl-D (Linuxes).'''

OUTRO = '#' * 105 + '''\n\nSetup done.\n\nPlease remember to setup Python CGIs on your webserver.
If you use Apache, you can copy this snippet into your http.conf file:\n
Alias %s "%s"
<Directory                    "%s">
    AllowOverride             None
    Order                     allow,deny
    Allow                     from all
    Options                   +ExecCGI +Indexes
    AddHandler                cgi-script cgi
    AddHandler                cgi-script py
    DirectoryIndex            index.cgi index.py index.html
</Directory>\n
Please test your installation at %s'''


############################################################################################################
# FUNCTIONS

def askForParameter(question, boolean=False, selectList=None, default=None, isFile=False, isDir=False):
    '''Ask user for a parameter.'''
    answer = default
    if boolean:
        # only ask for yes or no
        defaultstr = ""
        if default is True:
            defaultstr = " [yes]"
        elif default is False:
            default = False
            defaultstr = " [no]"
        answer = raw_input("%s%s " % (question, defaultstr))
        if answer is None or len(answer) == 0:
            answer = default
        while not answer in (True, False, "yes", "y", "no", "n"):
            print " Please choose yes or no."
            answer = raw_input("%s%s " % (question, defaultstr))
            if answer is None or len(answer) == 0:
                answer = default
        if answer in ('yes', 'y', True):
            answer = True
        else:
            answer = False
    elif isinstance(selectList, list) and len(selectList) > 0:
        i = 0
        selectDict = {}
        for option in selectList:
            selectDict[i] = option
            if default == option:
                default = i
            question += "\n  (%i) - %s" % (i, option)
        # ask question
        defaultstr = ""
        if default is not None:
            answer = raw_input("%s\nPlease select your option: [%s] " % (question, default))
            if answer is None or len(answer) == 0:
                answer = default
            while not answer in selectDict:
                print " Please select a valid option."
                answer = raw_input("%s\nPlease select your option: [%s] " % (question, default))
                if answer is None or len(answer) == 0:
                    answer = default
        else:
            answer = raw_input("%s\nPlease select your option: " % (question))
            while answer is None or not answer in selectDict:
                print " Please select a valid option."
                answer = raw_input("%s\nPlease select your option: " % (question))
        answer = selectDict[answer]
    else:
        defaultstr = ""
        if default is not None:
            answer = raw_input("%s [%s] " % (question, default))
            if answer is None or len(answer) == 0:
                answer = default
        else:
            answer = raw_input("%s " % (question))
            while answer is None or len(answer) == 0:
                print "Please enter something."
                answer = raw_input("%s " % (question))
        if isFile:
            # ensure its a file
            while not os.path.isfile(answer):
                print " The file does not exist. Please enter a valid filepath."
                answer = raw_input("%s%s " % (question, defaultstr))
        elif isDir:
            # ensure its a directory
            while not os.path.isdir(answer):
                print " The directory does not exist. Please enter a valid dirpath."
                answer = raw_input("%s%s " % (question, defaultstr))
    # print " --> %s" % str(answer)
    return answer


def updateBpsPathCfg(bpsPath):
    fn = os.path.join(bpsPath, 'lib', 'biocase', 'adjustpath.py')
    cfgF = file(fn, 'r')
    cfgF.readline()  # discard previous first line
    text = "bpsPath = r'%s'\n" % bpsPath
    text += cfgF.read()
    cfgF.close()
    # write back
    fw = file(fn, 'w')
    fw.write(text)
    fw.close()


def copytree(src, dst):
    # Modified version of the shutils function: Does not raise erros when dirs already exist, but skips them.
    cnt = 0

    for name in os.listdir(src):
        if name.startswith('.'):    # ignore SVN dirs
            continue
        srcname = os.path.join(src, name)
        dstname = os.path.join(dst, name)
        if os.path.isdir(srcname):
            # folder: check whether it already exists
            if os.path.isdir(dstname):
                print "  HINT: Data source %s already exists in new installation; will be skipped." % name
            else:
                try:
                    os.mkdir(dstname)
                    copytree(srcname, dstname)
                    cnt += 1
                except Exception, e:
                    print "  WARNING: Data source %s could not be imported (%s)." % (name, e)
        else:
            # file: simply copy
            shutil.copy2(srcname, dstname)

    return cnt


def importConfiguration(old_path, new_path):
    # Load old configuration and save it
    cfg = Cfg()
    cfg.reloadConfigFiles(bpsPath=old_path)
    save = cfg._getRecursiveDict()   # This is a dictionary: Sections have dictionaries as a value, attributes are strings/ints
    #                                 _getDict() would be the same as a simple (= flat) dictionary with sections in the format server.password = ...

    # Load configuration from new installation and change parameters that have been found in old config sections
    cfg.reloadConfigFiles(bpsPath=new_path)
    for section, section_value in save.items():
        if isinstance(section_value, dict):     # Only process dictionaries (= sections)
            for option, value in section_value.items():
                cfg._setOption(section, option, value)

    # Copy data sources and return cfg/count
    cnt = copytree(os.path.join(old_path, 'config', 'datasources'), os.path.join(new_path, 'config', 'datasources'))
    return cfg, cnt


############################################################################################################
# MAIN

# First, set some paths and check for Python version.
bpsPath = os.path.abspath('.')
liblocator = os.path.join(bpsPath, 'lib')
if (sys.version[:3] < '2.5'):
    print 'FATAL ERROR: This software requires Python 2.5+'
    sys.exit()

# Print intro text
print INTRO % (version, sys.executable, liblocator)

# update configuration.py libPath
try:
    updateBpsPathCfg(bpsPath)
    print "Absolute path to installation in configuration set to %s." % bpsPath
except Exception, e:
    print "\nERROR: Absolute path to installation could not be saved (%s).\nPlease resolve this problem and re-run the setup script." % e
    sys.exit()

# Ask for Update
updated = False
if askForParameter("\nDo you want to import the configuration of an older BPS installation (version 2.5+)?", boolean=True, default=False):
    try:
        path = None
        while path is None:
            path = os.path.abspath(askForParameter("\nPlease specify path to old BPS installation (either absolute or relative to %s):" % bpsPath, isDir=True))
            if os.path.normcase(path) == os.path.normcase(bpsPath):
                print " Specified installation is the same as this one."
                path = None
            else:
                if os.path.exists(os.path.join(path, "config", "config.ini")) and os.path.exists(os.path.join(path, "config", "namespaces.ini")):
                    print "\nImporting from %s..." % path
                    cfg, count = importConfiguration(path, bpsPath)
                    cfg.__save__()
                    print "  BioCASe configuration and %i data source(s) imported.\n" % count
                    updated = True
                else:
                    print " %s is not a valid BPS 2.5+ installation." % path
                    path = None
    except Exception, e:
        print "ERROR: %s\nConfiguration could not be imported.\n" % e
        if not askForParameter("Do you want to continue with manual configuration instead?", boolean=True, default=True):
            sys.exit()

if not updated:
    try:
        cfg = Cfg()
        cfg.server.host = askForParameter("\nPlease indicate the domain of your webserver:", default='http://localhost')
        cfg.server.webroot = askForParameter("Please indicate the base URL you are planning to use for the software:", default='/biocase')
        cfg.__save__()
        print
    except Exception, e:
        print "\nERROR: Configuration could not be saved (%s).\nPlease resolve this problem and re-run the setup script." % e
        sys.exit()

# run adapt2 tool
os.chdir(os.path.join(bpsPath, 'tools'))    # change current working directory to adapt script
print "Adapting file permissions and shebang lines for use with %s..." % sys.executable
execfile(os.path.join(bpsPath, 'tools', 'fixpermissions.py'))

# Outro
BpsWwwPath = os.path.join(bpsPath, "www")
print OUTRO % (cfg.server.webroot, BpsWwwPath, BpsWwwPath, cfg.getWebappURL())

==> provider_software_3.7.4.tar.gz: provider_software_3.7.4/setup.py <==
#!/usr/bin/env python

# ****************************************
# +++  BioCASE Provider Software
# +++  Installer script
# ****************************************

'''
$RCSfile: $
$Revision: 1554 $
$Author: j.holetschek $
$Date: 2018-04-23 11:30:34 +0200 (Mo, 23. Apr 2018) $
'''

import sys, os, shutil

# adjust syspath for biocase lib
execfile(os.path.abspath(os.path.join(os.path.dirname(__file__), 'lib', 'biocase', 'adjustpath.py')))

from biocase import __version__ as version
from biocase.configuration import Cfg

INTRO = '''
 +++  BioCASe Provider Software
 +++  Version %s
 +++  Installer script

 Configure BPS with:
 Python      %s
 BPS Library %s

This setup tool adapts the BioCASe Provider Software (BPS) to your system environment.
You can cancel it by hitting Ctrl-Z + Return (Windows) or Ctrl-D (Linuxes).'''

OUTRO = '#' * 105 + '''\n\nSetup done.\n\nPlease remember to setup Python CGIs on your webserver.
If you use Apache, you can copy this snippet into your http.conf file:\n
Alias %s "%s"
<Directory                    "%s">
    AllowOverride             None
    Order                     allow,deny
    Allow                     from all
    Options                   +ExecCGI +Indexes
    AddHandler                cgi-script cgi
    DirectoryIndex            index.cgi index.html
    Require all granted
</Directory>\n
Please test your installation at %s'''


############################################################################################################
# FUNCTIONS

def askForParameter(question, boolean=False, selectList=None, default=None, isFile=False, isDir=False):
    '''Ask user for a parameter.'''
    answer = default
    if boolean:
        # only ask for yes or no
        defaultstr = ""
        if default is True:
            defaultstr = " [yes]"
        elif default is False:
            default = False
            defaultstr = " [no]"
        answer = raw_input("%s%s " % (question, defaultstr))
        if answer is None or len(answer) == 0:
            answer = default
        while not answer in (True, False, "yes", "y", "no", "n"):
            print " Please choose yes or no."
            answer = raw_input("%s%s " % (question, defaultstr))
            if answer is None or len(answer) == 0:
                answer = default
        if answer in ('yes', 'y', True):
            answer = True
        else:
            answer = False
    elif isinstance(selectList, list) and len(selectList) > 0:
        i = 0
        selectDict = {}
        for option in selectList:
            selectDict[i] = option
            if default == option:
                default = i
            question += "\n  (%i) - %s" % (i, option)
        # ask question
        defaultstr = ""
        if default is not None:
            answer = raw_input("%s\nPlease select your option: [%s] " % (question, default))
            if answer is None or len(answer) == 0:
                answer = default
            while not answer in selectDict:
                print " Please select a valid option."
                answer = raw_input("%s\nPlease select your option: [%s] " % (question, default))
                if answer is None or len(answer) == 0:
                    answer = default
        else:
            answer = raw_input("%s\nPlease select your option: " % (question))
            while answer is None or not answer in selectDict:
                print " Please select a valid option."
                answer = raw_input("%s\nPlease select your option: " % (question))
        answer = selectDict[answer]
    else:
        defaultstr = ""
        if default is not None:
            answer = raw_input("%s [%s] " % (question, default))
            if answer is None or len(answer) == 0:
                answer = default
        else:
            answer = raw_input("%s " % (question))
            while answer is None or len(answer) == 0:
                print "Please enter something."
                answer = raw_input("%s " % (question))
        if isFile:
            # ensure its a file
            while not os.path.isfile(answer):
                print " The file does not exist. Please enter a valid filepath."
                answer = raw_input("%s%s " % (question, defaultstr))
        elif isDir:
            # ensure its a directory
            while not os.path.isdir(answer):
                print " The directory does not exist. Please enter a valid dirpath."
                answer = raw_input("%s%s " % (question, defaultstr))
    # print " --> %s" % str(answer)
    return answer


def updateBpsPathCfg(bpsPath):
    fn = os.path.join(bpsPath, 'lib', 'biocase', 'adjustpath.py')
    cfgF = file(fn, 'r')
    cfgF.readline()  # discard previous first line
    text = "bpsPath = r'%s'\n" % bpsPath
    text += cfgF.read()
    cfgF.close()
    # write back
    fw = file(fn, 'w')
    fw.write(text)
    fw.close()


def copytree(src, dst):
    # Modified version of the shutils function: Does not raise erros when dirs already exist, but skips them.
    cnt = 0

    for name in os.listdir(src):
        if name.startswith('.'):    # ignore SVN dirs
            continue
        srcname = os.path.join(src, name)
        dstname = os.path.join(dst, name)
        if os.path.isdir(srcname):
            # folder: check whether it already exists
            if os.path.isdir(dstname):
                print "  HINT: Data source %s already exists in new installation; will be skipped." % name
            else:
                try:
                    os.mkdir(dstname)
                    copytree(srcname, dstname)
                    cnt += 1
                except Exception, e:
                    print "  WARNING: Data source %s could not be imported (%s)." % (name, e)
        else:
            # file: simply copy
            shutil.copy2(srcname, dstname)

    return cnt


def importConfiguration(old_path, new_path):
    # Load old configuration and save it
    cfg = Cfg()
    cfg.reloadConfigFiles(bpsPath=old_path)
    save = cfg._getRecursiveDict()   # This is a dictionary: Sections have dictionaries as a value, attributes are strings/ints
    #                                 _getDict() would be the same as a simple (= flat) dictionary with sections in the format server.password = ...

    # Load configuration from new installation and change parameters that have been found in old config sections
    cfg.reloadConfigFiles(bpsPath=new_path)
    for section, section_value in save.items():
        if isinstance(section_value, dict):     # Only process dictionaries (= sections)
            for option, value in section_value.items():
                cfg._setOption(section, option, value)

    # Copy data sources and return cfg/count
    cnt = copytree(os.path.join(old_path, 'config', 'datasources'), os.path.join(new_path, 'config', 'datasources'))
    return cfg, cnt


############################################################################################################
# MAIN

# First, set some paths and check for Python version.
bpsPath = os.path.abspath('.')
liblocator = os.path.join(bpsPath, 'lib')
if (sys.version[:3] < '2.5'):
    print 'FATAL ERROR: This software requires Python 2.5+'
    sys.exit()

# Print intro text
print INTRO % (version, sys.executable, liblocator)

# update configuration.py libPath
try:
    updateBpsPathCfg(bpsPath)
    print "Absolute path to installation in configuration set to %s." % bpsPath
except Exception, e:
    print "\nERROR: Absolute path to installation could not be saved (%s).\nPlease resolve this problem and re-run the setup script." % e
    sys.exit()

# Ask for Update
updated = False
if askForParameter("\nDo you want to import the configuration of an older BPS installation (version 2.5+)?", boolean=True, default=False):
    try:
        path = None
        while path is None:
            path = os.path.abspath(askForParameter("\nPlease specify path to old BPS installation (either absolute or relative to %s):" % bpsPath, isDir=True))
            if os.path.normcase(path) == os.path.normcase(bpsPath):
                print " Specified installation is the same as this one."
                path = None
            else:
                if os.path.exists(os.path.join(path, "config", "config.ini")) and os.path.exists(os.path.join(path, "config", "namespaces.ini")):
                    print "\nImporting from %s..." % path
                    cfg, count = importConfiguration(path, bpsPath)
                    cfg.__save__()
                    print "  BioCASe configuration and %i data source(s) imported.\n" % count
                    updated = True
                else:
                    print " %s is not a valid BPS 2.5+ installation." % path
                    path = None
    except Exception, e:
        print "ERROR: %s\nConfiguration could not be imported.\n" % e
        if not askForParameter("Do you want to continue with manual configuration instead?", boolean=True, default=True):
            sys.exit()

if not updated:
    try:
        cfg = Cfg()
        cfg.server.host = askForParameter("\nPlease indicate the domain of your webserver:", default='http://localhost')
        cfg.server.webroot = askForParameter("Please indicate the base URL you are planning to use for the software:", default='/biocase')
        cfg.__save__()
        print
    except Exception, e:
        print "\nERROR: Configuration could not be loaded or saved (%s).\nPlease resolve this problem and re-run the setup script." % e
        sys.exit()

# run adapt2 tool
os.chdir(os.path.join(bpsPath, 'tools'))    # change current working directory to adapt script
print "Adapting file permissions and shebang lines for use with %s..." % sys.executable
execfile(os.path.join(bpsPath, 'tools', 'fixpermissions.py'))

# Outro
BpsWwwPath = os.path.join(bpsPath, "www")
print OUTRO % (cfg.server.webroot, BpsWwwPath, BpsWwwPath, cfg.getWebappURL())
